@@ -9,15 +9,15 @@
 #  ifndef QCOROCORE_EXPORT
 #    ifdef QCoro5Core_EXPORTS
         /* We are building this library */
-#      define QCOROCORE_EXPORT 
+#      define QCOROCORE_EXPORT __attribute__((visibility("default")))
 #    else
         /* We are using this library */
-#      define QCOROCORE_EXPORT 
+#      define QCOROCORE_EXPORT __attribute__((visibility("default")))
 #    endif
 #  endif
 
 #  ifndef QCOROCORE_NO_EXPORT
-#    define QCOROCORE_NO_EXPORT 
+#    define QCOROCORE_NO_EXPORT __attribute__((visibility("hidden")))
 #  endif
 #endif
 
@@ -33,6 +33,7 @@
 #  define QCOROCORE_DEPRECATED_NO_EXPORT QCOROCORE_NO_EXPORT QCOROCORE_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef QCOROCORE_NO_DEPRECATED
 #    define QCOROCORE_NO_DEPRECATED
