@@ -9,15 +9,15 @@
 #  ifndef QCORONETWORK_EXPORT
 #    ifdef QCoro5Network_EXPORTS
         /* We are building this library */
-#      define QCORONETWORK_EXPORT 
+#      define QCORONETWORK_EXPORT __attribute__((visibility("default")))
 #    else
         /* We are using this library */
-#      define QCORONETWORK_EXPORT 
+#      define QCORONETWORK_EXPORT __attribute__((visibility("default")))
 #    endif
 #  endif
 
 #  ifndef QCORONETWORK_NO_EXPORT
-#    define QCORONETWORK_NO_EXPORT 
+#    define QCORONETWORK_NO_EXPORT __attribute__((visibility("hidden")))
 #  endif
 #endif
 
@@ -33,6 +33,7 @@
 #  define QCORONETWORK_DEPRECATED_NO_EXPORT QCORONETWORK_NO_EXPORT QCORONETWORK_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef QCORONETWORK_NO_DEPRECATED
 #    define QCORONETWORK_NO_DEPRECATED
