@@ -9,15 +9,15 @@
 #  ifndef QCOROQML_EXPORT
 #    ifdef QCoro5Qml_EXPORTS
         /* We are building this library */
-#      define QCOROQML_EXPORT 
+#      define QCOROQML_EXPORT __attribute__((visibility("default")))
 #    else
         /* We are using this library */
-#      define QCOROQML_EXPORT 
+#      define QCOROQML_EXPORT __attribute__((visibility("default")))
 #    endif
 #  endif
 
 #  ifndef QCOROQML_NO_EXPORT
-#    define QCOROQML_NO_EXPORT 
+#    define QCOROQML_NO_EXPORT __attribute__((visibility("hidden")))
 #  endif
 #endif
 
@@ -33,6 +33,7 @@
 #  define QCOROQML_DEPRECATED_NO_EXPORT QCOROQML_NO_EXPORT QCOROQML_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef QCOROQML_NO_DEPRECATED
 #    define QCOROQML_NO_DEPRECATED
