@@ -9,15 +9,15 @@
 #  ifndef QCOROQUICK_EXPORT
 #    ifdef QCoro5Quick_EXPORTS
         /* We are building this library */
-#      define QCOROQUICK_EXPORT 
+#      define QCOROQUICK_EXPORT __attribute__((visibility("default")))
 #    else
         /* We are using this library */
-#      define QCOROQUICK_EXPORT 
+#      define QCOROQUICK_EXPORT __attribute__((visibility("default")))
 #    endif
 #  endif
 
 #  ifndef QCOROQUICK_NO_EXPORT
-#    define QCOROQUICK_NO_EXPORT 
+#    define QCOROQUICK_NO_EXPORT __attribute__((visibility("hidden")))
 #  endif
 #endif
 
@@ -33,6 +33,7 @@
 #  define QCOROQUICK_DEPRECATED_NO_EXPORT QCOROQUICK_NO_EXPORT QCOROQUICK_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef QCOROQUICK_NO_DEPRECATED
 #    define QCOROQUICK_NO_DEPRECATED
